@@ -19,6 +19,7 @@
 
 #include "elisa_settings.h"
 #include <KConfigCore/KAuthorized>
+#include <KLocalizedString>
 
 #if defined KF5ConfigWidgets_FOUND && KF5ConfigWidgets_FOUND
 #include <KConfigWidgets/KStandardAction>
@@ -32,7 +33,9 @@
 #include <KXmlGui/KShortcutsDialog>
 #endif
 
+#include <KColorSchemeManager>
 #include <KCoreAddons/KAboutData>
+#include <KIO/OpenFileManagerWindowJob>
 
 #include <QQmlEngine>
 #include <QQmlComponent>
@@ -88,6 +91,7 @@ public:
 
     QFileSystemWatcher mConfigFileWatcher;
 
+    KColorSchemeManager *mSchemes;
 };
 
 ElisaApplication::ElisaApplication(QObject *parent) : QObject(parent), d(std::make_unique<ElisaApplicationPrivate>(this))
@@ -98,6 +102,8 @@ ElisaApplication::ElisaApplication(QObject *parent) : QObject(parent), d(std::ma
     Elisa::ElisaConfiguration::self()->load();
     Elisa::ElisaConfiguration::self()->save();
 
+    d->mSchemes = new KColorSchemeManager(this);
+
     d->mConfigFileWatcher.addPath(Elisa::ElisaConfiguration::self()->config()->name());
 
     connect(Elisa::ElisaConfiguration::self(), &Elisa::ElisaConfiguration::configChanged,
@@ -113,6 +119,16 @@ ElisaApplication::ElisaApplication(QObject *parent) : QObject(parent), d(std::ma
 ElisaApplication::~ElisaApplication()
 = default;
 
+QAbstractItemModel *ElisaApplication::colorSchemesModel()
+{
+    return d->mSchemes->model();
+}
+
+void ElisaApplication::activateColorScheme(const QString &name)
+{
+    d->mSchemes->activateScheme(d->mSchemes->indexForScheme(name));
+}
+
 void ElisaApplication::setupActions(const QString &actionName)
 {
 #if defined KF5XmlGui_FOUND && KF5XmlGui_FOUND
@@ -154,21 +170,36 @@ void ElisaApplication::setupActions(const QString &actionName)
     if (actionName == QLatin1String("toggle_playlist") && KAuthorized::authorizeAction(actionName)) {
         auto togglePlaylistAction = d->mCollection.addAction(actionName, this, &ElisaApplication::togglePlaylist);
         togglePlaylistAction->setShortcut(QKeySequence(Qt::Key_F9));
-        togglePlaylistAction->setText(QStringLiteral("Toggle Playlist"));
+        togglePlaylistAction->setText(i18n("Toggle Playlist"));
     }
 
     if (actionName == QLatin1String("Seek") && KAuthorized::authorizeAction(actionName)) {
             auto seekAction = d->mCollection.addAction(actionName, this, &ElisaApplication::seek);
+            seekAction->setText(i18n("Seek forward 10 seconds"));
             d->mCollection.setDefaultShortcut(seekAction, QKeySequence(Qt::SHIFT + Qt::Key_Right));
     }
 
     if (actionName == QLatin1String("Scrub") && KAuthorized::authorizeAction(actionName)) {
             auto scrubAction = d->mCollection.addAction(actionName, this, &ElisaApplication::scrub);
+            scrubAction->setText(i18n("Scrub backwards 10 seconds"));
             d->mCollection.setDefaultShortcut(scrubAction, QKeySequence(Qt::SHIFT + Qt::Key_Left));
     }
 
+    if (actionName == QLatin1String("NextTrack") && KAuthorized::authorizeAction(actionName)) {
+            auto nextTrackAction = d->mCollection.addAction(actionName, this, &ElisaApplication::nextTrack);
+            nextTrackAction->setText(i18n("Go to next track"));
+            d->mCollection.setDefaultShortcut(nextTrackAction, QKeySequence(Qt::CTRL + Qt::Key_Left));
+    }
+
+    if (actionName == QLatin1String("PreviousTrack") && KAuthorized::authorizeAction(actionName)) {
+            auto previousTrackAction = d->mCollection.addAction(actionName, this, &ElisaApplication::previousTrack);
+            previousTrackAction->setText(i18n("Go to previous track"));
+            d->mCollection.setDefaultShortcut(previousTrackAction, QKeySequence(Qt::CTRL + Qt::Key_Right));
+    }
+
     if (actionName == QLatin1String("Play-Pause") && KAuthorized::authorizeAction(actionName)) {
             auto playPauseAction = d->mCollection.addAction(actionName, this, &ElisaApplication::playPause);
+            playPauseAction->setText(i18n("Play/pause"));
             d->mCollection.setDefaultShortcut(playPauseAction, QKeySequence(Qt::Key_Space));
     }
 
@@ -262,7 +293,7 @@ void ElisaApplication::reportBug()
 void ElisaApplication::configureShortcuts()
 {
 #if defined KF5XmlGui_FOUND && KF5XmlGui_FOUND
-    KShortcutsDialog dlg(KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsAllowed, nullptr);
+    KShortcutsDialog dlg(KShortcutsEditor::ApplicationAction, KShortcutsEditor::LetterShortcutsAllowed, nullptr);
     dlg.setModal(true);
     dlg.addCollection(&d->mCollection);
     dlg.configure();
@@ -292,6 +323,10 @@ void ElisaApplication::seek() {}
 
 void ElisaApplication::scrub() {}
 
+void ElisaApplication::nextTrack() {}
+
+void ElisaApplication::previousTrack() {}
+
 void ElisaApplication::playPause() {}
 
 void ElisaApplication::configChanged()
@@ -415,7 +450,7 @@ void ElisaApplication::initializePlayer()
     QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::currentTrackChanged, d->mAudioControl.get(), &ManageAudioPlayer::setCurrentTrack);
     QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::clearPlayListPlayer, d->mAudioControl.get(), &ManageAudioPlayer::saveForUndoClearPlaylist);
     QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::undoClearPlayListPlayer, d->mAudioControl.get(), &ManageAudioPlayer::restoreForUndoClearPlaylist);
-
+    QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::seek, d->mAudioWrapper.get(), &AudioWrapper::seek);
 
     QObject::connect(d->mAudioWrapper.get(), &AudioWrapper::playbackStateChanged,
                      d->mAudioControl.get(), &ManageAudioPlayer::setPlayerPlaybackState);
@@ -490,7 +525,7 @@ bool ElisaApplication::eventFilter(QObject *object, QEvent *event)
 {
     Q_UNUSED(object)
 
-    QKeyEvent *keyEvent = static_cast<QKeyEvent*>(event);
+    auto *keyEvent = static_cast<QKeyEvent*>(event);
     auto playPauseAction = d->mCollection.action(tr("Play-Pause"));
     if (keyEvent->key() == Qt::Key_Space && playPauseAction->shortcut()[0] == Qt::Key_Space) {
         return true;
@@ -499,6 +534,11 @@ bool ElisaApplication::eventFilter(QObject *object, QEvent *event)
     return false;
 }
 
+void ElisaApplication::showInFolder(QUrl filePath)
+{
+    KIO::highlightInFileManager({filePath});
+}
+
 const DataTypes::EntryDataList &ElisaApplication::arguments() const
 {
     return d->mArguments;
@@ -577,4 +617,11 @@ ElisaUtils::PlayListEntryType ElisaApplication::embeddedView() const
     return result;
 }
 
+int ElisaApplication::initialViewIndex() const
+{
+    int result = Elisa::ElisaConfiguration::initialView();
+
+    return result;
+}
+
 #include "moc_elisaapplication.cpp"
