@@ -1,18 +1,7 @@
 /*
- * Copyright 2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2017 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #if !defined ELISACONFIGURATIONDIALOG_H_
@@ -20,6 +9,8 @@
 
 #include "elisaLib_export.h"
 
+#include "elisautils.h"
+
 #include <QStringList>
 #include <QFileSystemWatcher>
 
@@ -48,38 +39,78 @@ class ELISALIB_EXPORT ElisaConfigurationDialog : public QObject
                WRITE setShowSystemTrayIcon
                NOTIFY showSystemTrayIconChanged)
 
+    Q_PROPERTY(ElisaUtils::PlayListEntryType embeddedView
+               READ embeddedView
+               WRITE setEmbeddedView
+               NOTIFY embeddedViewChanged)
+
+    Q_PROPERTY(int initialViewIndex
+               READ initialViewIndex
+               WRITE setInitialViewIndex
+               NOTIFY initialViewIndexChanged)
+
     Q_PROPERTY(bool isDirty
                READ isDirty
                NOTIFY isDirtyChanged)
 
+    Q_PROPERTY(bool playAtStartup
+               READ playAtStartup
+               WRITE setPlayAtStartup
+               NOTIFY playAtStartupChanged)
+
+        Q_PROPERTY(QString colorScheme
+                   READ colorScheme
+                   WRITE setColorScheme
+                   NOTIFY colorSchemeChanged)
+
 public:
 
     explicit ElisaConfigurationDialog(QObject *parent = nullptr);
 
     ~ElisaConfigurationDialog() override;
 
-    QStringList rootPath() const;
+    [[nodiscard]] QStringList rootPath() const;
 
-    bool isDirty() const
+    [[nodiscard]] bool isDirty() const
     {
         return mIsDirty;
     }
 
-    bool showProgressInTaskBar() const
+    [[nodiscard]] bool showProgressInTaskBar() const
     {
         return mShowProgressInTaskBar;
     }
 
-    bool showSystemTrayIcon() const
+    [[nodiscard]] bool showSystemTrayIcon() const
     {
         return mShowSystemTrayIcon;
     }
 
-    bool forceUsageOfFastFileSearch() const
+    [[nodiscard]] bool forceUsageOfFastFileSearch() const
     {
         return mForceUsageOfFastFileSearch;
     }
 
+    [[nodiscard]] ElisaUtils::PlayListEntryType embeddedView() const
+    {
+        return mEmbeddedView;
+    }
+
+    [[nodiscard]] int initialViewIndex() const
+    {
+        return mInitialViewIndex;
+    }
+
+    [[nodiscard]] bool playAtStartup() const
+    {
+        return mPlayAtStartup;
+    }
+
+    [[nodiscard]] QString colorScheme() const
+    {
+        return mColorScheme;
+    }
+
 Q_SIGNALS:
 
     void rootPathChanged(const QStringList &rootPath);
@@ -92,6 +123,14 @@ Q_SIGNALS:
 
     void forceUsageOfFastFileSearchChanged();
 
+    void embeddedViewChanged();
+
+    void initialViewIndexChanged();
+
+    void playAtStartupChanged();
+
+    void colorSchemeChanged();
+
 public Q_SLOTS:
 
     void setRootPath(const QStringList &rootPath);
@@ -104,6 +143,14 @@ public Q_SLOTS:
 
     void setForceUsageOfFastFileSearch(bool forceUsageOfFastFileSearch);
 
+    void setEmbeddedView(ElisaUtils::PlayListEntryType embeddedView);
+
+    void setInitialViewIndex(int initialViewIndex);
+
+    void setPlayAtStartup(bool playAtStartup);
+
+    void setColorScheme(const QString &scheme);
+
 private Q_SLOTS:
 
     void configChanged();
@@ -123,6 +170,14 @@ private:
     bool mShowSystemTrayIcon = false;
 
     bool mForceUsageOfFastFileSearch = true;
+
+    bool mPlayAtStartup = false;
+
+    QString mColorScheme;
+
+    ElisaUtils::PlayListEntryType mEmbeddedView = ElisaUtils::Unknown;
+
+    int mInitialViewIndex = 2;
 };
 
 #endif
