@@ -1,18 +1,7 @@
 /*
- * Copyright 2015-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2015 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #ifndef MEDIAPLAYLIST_H
@@ -82,10 +71,14 @@ public:
         ElementTypeRole,
         LyricsRole,
         FullDataRole,
+        IsDirectoryRole,
+        IsPlayListRole,
+        FilePathRole,
         IsValidRole,
         CountRole,
         IsPlayingRole,
         AlbumSectionRole,
+        MetadataModifiableRole,
     };
 
     Q_ENUM(ColumnsRoles)
@@ -106,13 +99,13 @@ public:
 
     ~MediaPlayList() override;
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
     bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
 
-    QHash<int, QByteArray> roleNames() const override;
+    [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
     bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;
 
@@ -122,7 +115,7 @@ public:
 
     void enqueueRestoredEntries(const QVariantList &newEntries);
 
-    QVariantList getEntriesForRestore() const;
+    [[nodiscard]] QVariantList getEntriesForRestore() const;
 
 Q_SIGNALS:
 
@@ -148,13 +141,11 @@ public Q_SLOTS:
 
     void trackInError(const QUrl &sourceInError, QMediaPlayer::Error playerError);
 
-    void enqueueFilesList(const ElisaUtils::EntryDataList &newEntries, ElisaUtils::PlayListEntryType databaseIdType);
+    void enqueueFilesList(const DataTypes::EntryDataList &newEntries);
 
-    void enqueueTracksListById(const ElisaUtils::EntryDataList &newEntries, ElisaUtils::PlayListEntryType type);
+    void enqueueOneEntry(const DataTypes::EntryData &entryData);
 
-    void enqueueOneEntry(const ElisaUtils::EntryData &entryData, ElisaUtils::PlayListEntryType type);
-
-    void enqueueMultipleEntries(const ElisaUtils::EntryDataList &entriesData, ElisaUtils::PlayListEntryType type);
+    void enqueueMultipleEntries(const DataTypes::EntryDataList &entriesData);
 
 private:
 
