@@ -12,6 +12,8 @@
 
 #include <QtConcurrent>
 
+#include <algorithm>
+
 TrackMetadataModel::TrackMetadataModel(QObject *parent)
     : QAbstractListModel(parent)
 {
@@ -32,7 +34,7 @@ int TrackMetadataModel::rowCount(const QModelIndex &parent) const
         return 0;
     }
 
-    return mTrackData.count();
+    return mTrackKeys.count();
 }
 
 QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
@@ -86,102 +88,23 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
             }
             break;
         }
+        case DataTypes::DurationRole:
+        {
+            auto trackDuration = mTrackData.duration();
+            if (trackDuration.hour() == 0) {
+                result = trackDuration.toString(QStringLiteral("mm:ss"));
+            } else {
+                result = trackDuration.toString();
+            }
+            break;
+        }
         default:
             result = mTrackData[currentKey];
             break;
         }
         break;
     case ItemNameRole:
-        switch (currentKey)
-        {
-        case DataTypes::TitleRole:
-            result = i18nc("Track title for track metadata view", "Title");
-            break;
-        case DataTypes::DurationRole:
-            result = i18nc("Duration label for track metadata view", "Duration");
-            break;
-        case DataTypes::ArtistRole:
-            result = i18nc("Track artist for track metadata view", "Artist");
-            break;
-        case DataTypes::AlbumRole:
-            result = i18nc("Album name for track metadata view", "Album");
-            break;
-        case DataTypes::AlbumArtistRole:
-            result = i18nc("Album artist for track metadata view", "Album Artist");
-            break;
-        case DataTypes::TrackNumberRole:
-            result = i18nc("Track number for track metadata view", "Track Number");
-            break;
-        case DataTypes::DiscNumberRole:
-            result = i18nc("Disc number for track metadata view", "Disc Number");
-            break;
-        case DataTypes::RatingRole:
-            result = i18nc("Rating label for information panel", "Rating");
-            break;
-        case DataTypes::GenreRole:
-            result = i18nc("Genre label for track metadata view", "Genre");
-            break;
-        case DataTypes::LyricistRole:
-            result = i18nc("Lyricist label for track metadata view", "Lyricist");
-            break;
-        case DataTypes::ComposerRole:
-            result = i18nc("Composer name for track metadata view", "Composer");
-            break;
-        case DataTypes::CommentRole:
-            result = i18nc("Comment label for track metadata view", "Comment");
-            break;
-        case DataTypes::YearRole:
-            result = i18nc("Year label for track metadata view", "Year");
-            break;
-        case DataTypes::ChannelsRole:
-            result = i18nc("Channels label for track metadata view", "Channels");
-            break;
-        case DataTypes::BitRateRole:
-            result = i18nc("Bit rate label for track metadata view", "Bit Rate");
-            break;
-        case DataTypes::SampleRateRole:
-            result = i18nc("Sample Rate label for track metadata view", "Sample Rate");
-            break;
-        case DataTypes::LastPlayDate:
-            result = i18nc("Last play date label for track metadata view", "Last played");
-            break;
-        case DataTypes::PlayCounter:
-            result = i18nc("Play counter label for track metadata view", "Play count");
-            break;
-        case DataTypes::LyricsRole:
-            result = i18nc("Lyrics label for track metadata view", "Lyrics");
-            break;
-        case DataTypes::ResourceRole:
-            result = i18nc("Radio HTTP address for radio metadata view", "Stream Http Address");
-            break;
-        case DataTypes::ImageUrlRole:
-            result = i18nc("Image address for radio metadata view", "Image Address");
-            break;
-        case DataTypes::SecondaryTextRole:
-        case DataTypes::ShadowForImageRole:
-        case DataTypes::ChildModelRole:
-        case DataTypes::StringDurationRole:
-        case DataTypes::IsValidAlbumArtistRole:
-        case DataTypes::AllArtistsRole:
-        case DataTypes::HighestTrackRating:
-        case DataTypes::IdRole:
-        case DataTypes::ParentIdRole:
-        case DataTypes::DatabaseIdRole:
-        case DataTypes::IsSingleDiscAlbumRole:
-        case DataTypes::ContainerDataRole:
-        case DataTypes::IsPartialDataRole:
-        case DataTypes::AlbumIdRole:
-        case DataTypes::HasEmbeddedCover:
-        case DataTypes::FileModificationTime:
-        case DataTypes::FirstPlayDate:
-        case DataTypes::PlayFrequency:
-        case DataTypes::ElementTypeRole:
-        case DataTypes::FullDataRole:
-        case DataTypes::IsDirectoryRole:
-        case DataTypes::IsPlayListRole:
-        case DataTypes::FilePathRole:
-            break;
-        }
+        result = nameFromRole(currentKey);
         break;
     case ItemTypeRole:
         switch (currentKey)
@@ -235,10 +158,21 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
         case DataTypes::LyricsRole:
             result = LongTextEntry;
             break;
-        case DataTypes::DurationRole:
         case DataTypes::SampleRateRole:
+            result = IntegerEntry;
+            break;
         case DataTypes::BitRateRole:
+            result = IntegerEntry;
+            break;
         case DataTypes::ChannelsRole:
+            result = IntegerEntry;
+            break;
+        case DataTypes::FirstPlayDate:
+            result = DateEntry;
+            break;
+        case DataTypes::DurationRole:
+            result = DurationEntry;
+            break;
         case DataTypes::SecondaryTextRole:
         case DataTypes::ShadowForImageRole:
         case DataTypes::ChildModelRole:
@@ -255,7 +189,6 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
         case DataTypes::AlbumIdRole:
         case DataTypes::HasEmbeddedCover:
         case DataTypes::FileModificationTime:
-        case DataTypes::FirstPlayDate:
         case DataTypes::PlayFrequency:
         case DataTypes::ElementTypeRole:
         case DataTypes::FullDataRole:
@@ -336,12 +269,15 @@ void TrackMetadataModel::trackData(const TrackMetadataModel::TrackDataType &trac
     }
 
     const QList<DataTypes::ColumnsRoles> fieldsForTrack({DataTypes::TitleRole, DataTypes::ArtistRole,
-                                                                 DataTypes::AlbumRole, DataTypes::AlbumArtistRole,
-                                                                 DataTypes::TrackNumberRole, DataTypes::DiscNumberRole,
-                                                                 DataTypes::RatingRole, DataTypes::GenreRole,
-                                                                 DataTypes::LyricistRole, DataTypes::ComposerRole,
-                                                                 DataTypes::CommentRole, DataTypes::YearRole,
-                                                                 DataTypes::LastPlayDate, DataTypes::PlayCounter});
+                                                         DataTypes::AlbumRole, DataTypes::AlbumArtistRole,
+                                                         DataTypes::TrackNumberRole, DataTypes::DiscNumberRole,
+                                                         DataTypes::RatingRole, DataTypes::GenreRole,
+                                                         DataTypes::LyricistRole, DataTypes::ComposerRole,
+                                                         DataTypes::CommentRole, DataTypes::YearRole,
+                                                         DataTypes::ChannelsRole, DataTypes::BitRateRole,
+                                                         DataTypes::SampleRateRole, DataTypes::LyricsRole,
+                                                         DataTypes::LastPlayDate, DataTypes::PlayCounter,
+                                                         DataTypes::DurationRole});
 
     fillDataFromTrackData(trackData, fieldsForTrack);
 }
@@ -407,7 +343,7 @@ void TrackMetadataModel::fillLyricsDataFromTrack()
 
 const TrackMetadataModel::TrackDataType &TrackMetadataModel::allTrackData() const
 {
-    return mTrackData;
+    return mFullData;
 }
 
 void TrackMetadataModel::lyricsValueIsReady()
@@ -423,12 +359,16 @@ void TrackMetadataModel::lyricsValueIsReady()
 
 void TrackMetadataModel::initializeByIdAndUrl(ElisaUtils::PlayListEntryType type, qulonglong databaseId, const QUrl &url)
 {
-    mFullData.clear();
-    mTrackData.clear();
-    mCoverImage.clear();
-    mFileUrl.clear();
+    if (!mFullData.isEmpty()) {
+        beginResetModel();
+        mFullData.clear();
+        mTrackData.clear();
+        mCoverImage.clear();
+        mFileUrl.clear();
+        endResetModel();
 
-    Q_EMIT lyricsChanged();
+        Q_EMIT lyricsChanged();
+    }
 
     mFileUrl = url;
     mDatabaseId = databaseId;
@@ -455,10 +395,6 @@ void TrackMetadataModel::initialize(MusicListenersManager *newManager, DatabaseI
             &mDataLoader, &ModelDataLoader::loadDataByDatabaseIdAndUrl);
     connect(this, &TrackMetadataModel::needDataByUrl,
             &mDataLoader, &ModelDataLoader::loadDataByUrl);
-    connect(this, &TrackMetadataModel::saveRadioData,
-            &mDataLoader, &ModelDataLoader::saveRadioModified);
-    connect(this, &TrackMetadataModel::deleteRadioData,
-            &mDataLoader, &ModelDataLoader::removeRadio);
     connect(&mDataLoader, &ModelDataLoader::trackModified,
             this, &TrackMetadataModel::trackData);
     connect(&mDataLoader, &ModelDataLoader::allTrackData,
@@ -471,6 +407,178 @@ void TrackMetadataModel::initialize(MusicListenersManager *newManager, DatabaseI
             this, &TrackMetadataModel::radioData);
 }
 
+ModelDataLoader &TrackMetadataModel::modelDataLoader()
+{
+    return mDataLoader;
+}
+
+const TrackMetadataModel::TrackDataType &TrackMetadataModel::displayedTrackData() const
+{
+    return mTrackData;
+}
+
+DataTypes::ColumnsRoles TrackMetadataModel::trackKey(int index) const
+{
+    return mTrackKeys[index];
+}
+
+void TrackMetadataModel::removeDataByIndex(int index)
+{
+    auto dataKey = mTrackKeys[index];
+
+    mTrackData[dataKey] = {};
+    mFullData[dataKey] = {};
+    mTrackKeys.removeAt(index);
+}
+
+void TrackMetadataModel::addDataByName(const QString &name)
+{
+    DataTypes::ColumnsRoles newRole = DataTypes::TitleRole;
+
+    if (name == i18nc("Track title for track metadata view", "Title")) {
+        newRole = DataTypes::TitleRole;
+    } else if (name == i18nc("Track artist for track metadata view", "Artist")) {
+        newRole = DataTypes::ArtistRole;
+    } else if (name == i18nc("Album name for track metadata view", "Album")) {
+        newRole = DataTypes::AlbumRole;
+    } else if (name == i18nc("Album artist for track metadata view", "Album Artist")) {
+        newRole = DataTypes::AlbumArtistRole;
+    } else if (name == i18nc("Track number for track metadata view", "Track Number")) {
+        newRole = DataTypes::TrackNumberRole;
+    } else if (name == i18nc("Disc number for track metadata view", "Disc Number")) {
+        newRole = DataTypes::DiscNumberRole;
+    } else if (name == i18nc("Rating label for information panel", "Rating")) {
+        newRole = DataTypes::RatingRole;
+    } else if (name == i18nc("Genre label for track metadata view", "Genre")) {
+        newRole = DataTypes::GenreRole;
+    } else if (name == i18nc("Lyricist label for track metadata view", "Lyricist")) {
+        newRole = DataTypes::LyricistRole;
+    } else if (name == i18nc("Composer name for track metadata view", "Composer")) {
+        newRole = DataTypes::ComposerRole;
+    } else if (name == i18nc("Comment label for track metadata view", "Comment")) {
+        newRole = DataTypes::CommentRole;
+    } else if (name == i18nc("Year label for track metadata view", "Year")) {
+        newRole = DataTypes::YearRole;
+    } else if (name == i18nc("Channels label for track metadata view", "Channels")) {
+        newRole = DataTypes::ChannelsRole;
+    } else if (name == i18nc("Bit rate label for track metadata view", "Bit Rate")) {
+        newRole = DataTypes::BitRateRole;
+    } else if (name == i18nc("Sample Rate label for track metadata view", "Sample Rate")) {
+        newRole = DataTypes::SampleRateRole;
+    } else if (name == i18nc("Lyrics label for track metadata view", "Lyrics")) {
+        newRole = DataTypes::LyricsRole;
+    } else if (name == i18nc("Duration label for track metadata view", "Duration")) {
+        newRole = DataTypes::DurationRole;
+    }
+
+    mTrackData[newRole] = {};
+    mFullData[newRole] = {};
+    mTrackKeys.push_back(newRole);
+}
+
+QString TrackMetadataModel::nameFromRole(DataTypes::ColumnsRoles role)
+{
+    auto result = QString{};
+    switch (role)
+    {
+    case DataTypes::TitleRole:
+        result = i18nc("Track title for track metadata view", "Title");
+        break;
+    case DataTypes::DurationRole:
+        result = i18nc("Duration label for track metadata view", "Duration");
+        break;
+    case DataTypes::ArtistRole:
+        result = i18nc("Track artist for track metadata view", "Artist");
+        break;
+    case DataTypes::AlbumRole:
+        result = i18nc("Album name for track metadata view", "Album");
+        break;
+    case DataTypes::AlbumArtistRole:
+        result = i18nc("Album artist for track metadata view", "Album Artist");
+        break;
+    case DataTypes::TrackNumberRole:
+        result = i18nc("Track number for track metadata view", "Track Number");
+        break;
+    case DataTypes::DiscNumberRole:
+        result = i18nc("Disc number for track metadata view", "Disc Number");
+        break;
+    case DataTypes::RatingRole:
+        result = i18nc("Rating label for information panel", "Rating");
+        break;
+    case DataTypes::GenreRole:
+        result = i18nc("Genre label for track metadata view", "Genre");
+        break;
+    case DataTypes::LyricistRole:
+        result = i18nc("Lyricist label for track metadata view", "Lyricist");
+        break;
+    case DataTypes::ComposerRole:
+        result = i18nc("Composer name for track metadata view", "Composer");
+        break;
+    case DataTypes::CommentRole:
+        result = i18nc("Comment label for track metadata view", "Comment");
+        break;
+    case DataTypes::YearRole:
+        result = i18nc("Year label for track metadata view", "Year");
+        break;
+    case DataTypes::ChannelsRole:
+        result = i18nc("Channels label for track metadata view", "Channels");
+        break;
+    case DataTypes::BitRateRole:
+        result = i18nc("Bit rate label for track metadata view", "Bit Rate");
+        break;
+    case DataTypes::SampleRateRole:
+        result = i18nc("Sample Rate label for track metadata view", "Sample Rate");
+        break;
+    case DataTypes::LastPlayDate:
+        result = i18nc("Last play date label for track metadata view", "Last played");
+        break;
+    case DataTypes::FirstPlayDate:
+        result = i18nc("First play date label for track metadata view", "First played");
+        break;
+    case DataTypes::PlayCounter:
+        result = i18nc("Play counter label for track metadata view", "Play count");
+        break;
+    case DataTypes::LyricsRole:
+        result = i18nc("Lyrics label for track metadata view", "Lyrics");
+        break;
+    case DataTypes::ResourceRole:
+        result = i18nc("Radio HTTP address for radio metadata view", "Stream Http Address");
+        break;
+    case DataTypes::ImageUrlRole:
+        result = i18nc("Image address for radio metadata view", "Image Address");
+        break;
+    case DataTypes::SecondaryTextRole:
+    case DataTypes::ShadowForImageRole:
+    case DataTypes::ChildModelRole:
+    case DataTypes::StringDurationRole:
+    case DataTypes::IsValidAlbumArtistRole:
+    case DataTypes::AllArtistsRole:
+    case DataTypes::HighestTrackRating:
+    case DataTypes::IdRole:
+    case DataTypes::ParentIdRole:
+    case DataTypes::DatabaseIdRole:
+    case DataTypes::IsSingleDiscAlbumRole:
+    case DataTypes::ContainerDataRole:
+    case DataTypes::IsPartialDataRole:
+    case DataTypes::AlbumIdRole:
+    case DataTypes::HasEmbeddedCover:
+    case DataTypes::FileModificationTime:
+    case DataTypes::PlayFrequency:
+    case DataTypes::ElementTypeRole:
+    case DataTypes::FullDataRole:
+    case DataTypes::IsDirectoryRole:
+    case DataTypes::IsPlayListRole:
+    case DataTypes::FilePathRole:
+        break;
+    }
+    return result;
+}
+
+bool TrackMetadataModel::metadataExists(DataTypes::ColumnsRoles metadataRole) const
+{
+    return std::find(mTrackKeys.begin(), mTrackKeys.end(), metadataRole) != mTrackKeys.end();
+}
+
 void TrackMetadataModel::fetchLyrics()
 {
     auto lyricicsValue = QtConcurrent::run(QThreadPool::globalInstance(), [=]() {
@@ -495,22 +603,23 @@ void TrackMetadataModel::initializeForNewRadio()
 void TrackMetadataModel::fillDataForNewRadio()
 {
     beginResetModel();
+    mFullData.clear();
     mTrackData.clear();
     mTrackKeys.clear();
 
     auto allRoles = {DataTypes::TitleRole, DataTypes::ResourceRole,
-                     DataTypes::CommentRole, DataTypes::ImageUrlRole,
-                     DataTypes::DatabaseIdRole};
+                     DataTypes::CommentRole, DataTypes::ImageUrlRole};
 
     for (auto role : allRoles) {
         mTrackKeys.push_back(role);
         if (role == DataTypes::DatabaseIdRole) {
-            mTrackData[role] = -1;
+            mFullData[role] = -1;
         } else {
-            mTrackData[role] = QString();
+            mFullData[role] = QString();
         }
-
     }
+    mTrackData = mFullData;
+    mFullData[DataTypes::ElementTypeRole] = ElisaUtils::Radio;
     filterDataFromTrackData();
     endResetModel();
 }
@@ -539,13 +648,6 @@ void TrackMetadataModel::setDatabase(DatabaseInterface *trackDatabase)
     initialize(nullptr, trackDatabase);
 }
 
-void TrackMetadataModel::deleteRadio()
-{
-    if (mTrackData[DataTypes::DatabaseIdRole].toULongLong()) {
-        Q_EMIT deleteRadioData(mTrackData[DataTypes::DatabaseIdRole].toULongLong());
-    }
-}
-
 void TrackMetadataModel::radioData(const TrackDataType &radiosData)
 {
     if (!mFullData.isEmpty() && mFullData[DataTypes::DatabaseIdRole].toInt() != -1 &&
@@ -554,8 +656,7 @@ void TrackMetadataModel::radioData(const TrackDataType &radiosData)
     }
 
     const QList<DataTypes::ColumnsRoles> fieldsForTrack({DataTypes::TitleRole, DataTypes::ResourceRole,
-                                                                 DataTypes::CommentRole, DataTypes::ImageUrlRole,
-                                                                 DataTypes::DatabaseIdRole});
+                                                                 DataTypes::CommentRole, DataTypes::ImageUrlRole});
 
     fillDataFromTrackData(radiosData, fieldsForTrack);
 }
