@@ -31,6 +31,11 @@ class ELISALIB_EXPORT ViewManager : public QObject
                READ viewIndex
                NOTIFY viewIndexChanged)
 
+    Q_PROPERTY(int initialIndex
+               READ initialIndex
+               WRITE setInitialIndex
+               NOTIFY initialIndexChanged)
+
     Q_PROPERTY(ViewsListData* viewsData READ viewsData WRITE setViewsData NOTIFY viewsDataChanged)
 
 public:
@@ -98,9 +103,11 @@ public:
 
     ~ViewManager() override;
 
-    int viewIndex() const;
+    [[nodiscard]] int viewIndex() const;
 
-    ViewsListData* viewsData() const;
+    [[nodiscard]] int initialIndex() const;
+
+    [[nodiscard]] ViewsListData* viewsData() const;
 
 Q_SIGNALS:
 
@@ -116,6 +123,8 @@ Q_SIGNALS:
 
     void viewIndexChanged();
 
+    void initialIndexChanged();
+
     void viewsDataChanged();
 
 public Q_SLOTS:
@@ -128,12 +137,24 @@ public Q_SLOTS:
 
     void openArtistView(const QString &artist);
 
+    void openNowPlaying();
+
     void viewIsLoaded();
 
     void goBack();
 
     void setViewsData(ViewsListData* viewsData);
 
+    void sortOrderChanged(Qt::SortOrder sortOrder);
+
+    void sortRoleChanged(int sortRole);
+
+    void setInitialIndex(int newIndex);
+
+private Q_SLOTS:
+
+    void openInitialView();
+
 private:
 
     void openViewFromData(const ViewParameters &viewParamaters);
@@ -141,6 +162,14 @@ private:
     void applyFilter(ViewParameters &nextViewParameters,
                      QString title, const ViewParameters &lastView) const;
 
+    [[nodiscard]] QString buildViewId() const;
+
+    QStringList::iterator findViewPreference(QStringList &list, const QString &viewId) const;
+
+    [[nodiscard]] Qt::SortOrder computePreferredSortOrder(Qt::SortOrder initialValue) const;
+
+    [[nodiscard]] int computePreferredSortRole(int initialValue) const;
+
 private:
 
     std::unique_ptr<ViewManagerPrivate> d;
